$logFilePath = "C:\Program Files\NEC\LBFOStart.log"

$currentDate = Get-Date -Format "yyyy-MM-dd HH:mm:ss"

# Action to be taken if log files are missing
if (!(Test-Path $logFilePath)) {
    New-Item -Path $logFilePath -ItemType File -Force
}

function WriteLogFile($p1) {
    $currentDate = Get-Date -Format "yyyy-MM-dd HH:mm:ss"
    Add-Content -Path $logFilePath -Value "${currentDate}: ${p1}" -Force
}

WriteLogFile("LBFOStart Script Start. ${PID}")

# Wait for 300 seconds
Start-Sleep -Seconds 300

# Start the LBFO MsLbfoProvider service
Start-Service -Name 'MsLbfoProvider' -PassThru | Out-File $logFilePath -Append

# Obtain a valid network interface
$enabledInterfaces = Get-NetAdapter | Where-Object {
    $_.Status -eq 'Up' -and $_.InterfaceDescription -like 'Stratus*'
}
 
# Output the valid interface name
if ($enabledInterfaces.Count -eq 0) {
    WriteLogFile("No enabled network interfaces found with description starting with 'Stratus'.")
} else {
    WriteLogFile("Enabled network interfaces with description starting with 'Stratus':")
    $enabledInterfaces | ForEach-Object { WriteLogFile($_.Name) } 
}
 
# Disable the active interface
foreach ($adapter in $enabledInterfaces) {
    WriteLogFile("Disabling interface: $($adapter.Name)")
    Disable-NetAdapter -Name $adapter.Name -Confirm:$false -PassThru | Out-File $logFilePath -Append
}
 
# Wait for 5 seconds after the deactivation is complete
Start-Sleep -Seconds 5
 
# Re-enable the previously saved interface
foreach ($adapter in $enabledInterfaces) {
    WriteLogFile("Enabling interface: $($adapter.Name)")
    Enable-NetAdapter -Name $adapter.Name -Confirm:$false -PassThru | Out-File $logFilePath -Append
}
 
WriteLogFile("All applicable interfaces have been re-enabled.")

